==> pegasus-component-api-1.0.0-sources.jar: com/thebeastshop/pegasus/component/vo/CouponVO.java <==
package com.thebeastshop.pegasus.component.vo;

import java.util.Date;

/**
 * @author gongjun
 * @since 2016-07-14
 */
public class CouponVO {

    private Long id;

    private Long couponSampleId;

    private Long ownerId;

    private Integer isUsed;

    private Integer isValid;

    private String note;

    private Date startTime;

    private Date expireTime;

    private Date createTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCouponSampleId() {
        return couponSampleId;
    }

    public void setCouponSampleId(Long couponSampleId) {
        this.couponSampleId = couponSampleId;
    }

    public Long getOwnerId() {
        return ownerId;
    }

    public void setOwnerId(Long ownerId) {
        this.ownerId = ownerId;
    }

    public Integer getIsUsed() {
        return isUsed;
    }

    public void setIsUsed(Integer isUsed) {
        this.isUsed = isUsed;
    }

    public Integer getIsValid() {
        return isValid;
    }

    public void setIsValid(Integer isValid) {
        this.isValid = isValid;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }
}

==> pegasus-component-api-1.0.1-sources.jar: com/thebeastshop/pegasus/component/vo/CouponVO.java <==
package com.thebeastshop.pegasus.component.vo;

import java.util.Date;

/**
 * @author gongjun
 * @since 2016-07-14
 */
public class CouponVO {

    private Long id;

    private Long couponSampleId;

    private Long ownerId;

    private Integer isUsed;

    private Integer isValid;

    private String note;

    private Date startTime;

    private Date expireTime;

    private Date createTime;

    private String nickName;

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCouponSampleId() {
        return couponSampleId;
    }

    public void setCouponSampleId(Long couponSampleId) {
        this.couponSampleId = couponSampleId;
    }

    public Long getOwnerId() {
        return ownerId;
    }

    public void setOwnerId(Long ownerId) {
        this.ownerId = ownerId;
    }

    public Integer getIsUsed() {
        return isUsed;
    }

    public void setIsUsed(Integer isUsed) {
        this.isUsed = isUsed;
    }

    public Integer getIsValid() {
        return isValid;
    }

    public void setIsValid(Integer isValid) {
        this.isValid = isValid;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }
}
